@@ -26,7 +26,7 @@ use Class::Accessor::Lite
     )]
 ;
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 sub load_plugin {
     my ($class, $pkg, $opt) = @_;
@@ -348,6 +348,7 @@ sub insert {
     my ($self, $table_name, $args, $prefix) = @_;
 
     $self->do_insert($table_name, $args, $prefix);
+    return unless defined wantarray;
 
     my $table = $self->schema->get_table($table_name);
     my $pk = $table->primary_keys();
@@ -384,7 +385,7 @@ sub insert {
 }
 
 sub bulk_insert {
-    my ($self, $table_name, $args) = @_;
+    my ($self, $table_name, $args, $opt) = @_;
 
     return unless scalar(@{$args||[]});
 
@@ -408,14 +409,14 @@ sub bulk_insert {
             }
         }
 
-        my ($sql, @binds) = $self->sql_builder->insert_multi( $table_name, $args );
+        my ($sql, @binds) = $self->sql_builder->insert_multi( $table_name, $args, $opt );
         $self->execute($sql, \@binds);
     } else {
         # use transaction for better performance and atomicity.
         my $txn = $self->txn_scope();
         for my $arg (@$args) {
             # do not run trigger for consistency with mysql.
-            $self->insert($table_name, $arg);
+            $self->insert($table_name, $arg, $opt->{prefix});
         }
         $txn->commit;
     }
@@ -909,7 +910,7 @@ insert new record and get last_insert_id.
 
 no creation row object.
 
-=item C<$teng-E<gt>bulk_insert($table_name, \@rows_data)>
+=item C<$teng-E<gt>bulk_insert($table_name, \@rows_data, \%opt)>
 
 Accepts either an arrayref of hashrefs.
 each hashref should be a structure suitable
@@ -935,6 +936,8 @@ example:
         },
     ]);
 
+You can specify C<$opt> like C<< { prefix => 'INSERT IGNORE INTO' } >> or C<< { update => { name => 'updated' } } >> optionally, which will be passed to query builder.
+
 =item C<$update_row_count = $teng-E<gt>update($table_name, \%update_row_data, [\%update_condition])>
 
 Calls UPDATE on C<$table_name>, with values specified in C<%update_ro_data>, and returns the number of rows updated. You may optionally specify C<%update_condition> to create a conditional update query.
